#!/bin/bash
# packager           : Frederic Boulet <bipbip> bipbiponlinux~AT~gmail.com
# source location    : http://gparted.sourceforge.net/index.php
# last revised       : 16.02.2011

softname='gparted'
softversion='0.8.0'
packageversion='70.1'

arch='i686'
cpu='i686'

# log ;)
(

# parameters needed for the build process
buildir=$(pwd)
srcpkg="$buildir/$softname-$softversion.tar.bz2"
src="$buildir/$softname-$softversion"
package="$softname-$softversion-$arch-$packageversion"
dest="$buildir/$package"
source=http://kent.dl.sourceforge.net/sourceforge/gparted/$softname-$softversion.tar.bz2

# prepare the build result directory
dest="$buildir/$package"
rm -rf $dest
mkdir -p $dest
mkdir -p $dest/install
mkdir -p $dest/usr/share/applications
mkdir -p $dest/usr/share/icons/hicolor/48x48/apps/
mkdir -p $dest/usr/src/$softname-$softversion

# Slack-desc
cat <<EOF > $dest/install/slack-desc
       |-----handy-ruler------------------------------------------------------|
gparted: gparted (Parted GTK2 Frontend)
gparted: 
gparted: GParted is the Gnome Partition Editor application. 
gparted: GParted uses GNU libparted to detect and manipulate 
gparted: devices and partition tables.
gparted: 
gparted: 
gparted: 
gparted: 
gparted:
gparted: 
EOF

# check if source is present
if [ -f $softname-$softversion.tar.bz2 ]; then
	echo "Source file already here, no need to download";
else
 	echo "Downloading source"
	wget -c --no-check-certificate $source
fi

# extract the source code
cd $buildir
tar xvf $srcpkg
cd $src

# build

    export CFLAGS="-O2 -march=$arch -mtune=$cpu"
    export CXXFLAGS="-O2 -march=$arch -mtune=$cpu"

    ./configure \
      --prefix=/usr \
      --enable-static=no \
      --program-prefix="" \
      --program-suffix="" \
      --mandir=/usr/man \
      --build=$arch-slackware-linux

    make
    make install DESTDIR=$dest

# add 'default' files
    mkdir -p $dest/usr/doc/$softname-$softversion
    cp -a \
      AUTHORS COPYING INSTALL NEWS README ChangeLog \
      $dest/usr/doc/$softname-$softversion

# Strip Executables
( cd $dest
  find . | xargs file | grep "executable" | grep ELF | cut -f 1 -d : | xargs strip --strip-unneeded 2> /dev/null
  find . | xargs file | grep "shared object" | grep ELF | cut -f 1 -d : | xargs strip --strip-unneeded 2> /dev/null
)

# Compress man pages
( cd $dest/usr/man
  find . -name "*.?" | xargs gzip -9
)

# make the .desktop file
cat << "EOF" > $dest/usr/share/applications/$softname.desktop 
[Desktop Entry]
Encoding=UTF-8
Name=GParted
Name[bg]=GParted
Name[ca]=GParted
Name[cs]=GParted
Name[de]=GParted
Name[el]=GParted
Name[en_CA]=GParted
Name[en_GB]=GParted
Name[es]=GParted
Name[fi]=GParted
Name[fr]=GParted
Name[gl]=GParted
Name[he]=GParted
Name[hu]=GParted
Name[it]=GParted
Name[lt]=GParted
Name[mk]=Гпартед
Name[ne]=जिपार्टेड
Name[nl]=GParted
Name[pa]=GParted
Name[pl]=GParted
Name[pt]=GParted
Name[pt_BR]=GParted
Name[ru]=GParted
Name[sv]=GParted
Name[tr]=GParted
Name[uk]=GParted
Name[vi]=GParted
Name[zh_CN]=GParted
Name[zh_TW]=GParted
Comment=GNOME Partition Editor
Comment[bg]=Редактор на дялове на диск за GNOME
Comment[ca]=Editor de particions del GNOME
Comment[en_CA]=GNOME Partition Editor
Comment[es]=Editor de particiones de Gnome
Comment[fi]=Gnomen levyosioiden muokkain
Comment[fr]=Editeur de partitions
Comment[gl]=Editor de particións de Gnome
Comment[hu]=GNOME partíciószerkesztő
Comment[mk]=Уредувач на партиции за Гном
Comment[nl]=GNOME Partitiebewerker
Comment[pa]=ਗਨੋਮ ਭਾਗ ਸੰਪਾਦਕ
Comment[pt_BR]=Editor de Partições do GNOME
Comment[sv]=Partitionsredigerare för GNOME
Comment[tr]=GNOME Bölümleme Düzenleyicisi
Comment[vi]=Bộ hiệu chỉnh phân vùng Gnome
Exec=gksu gparted
Icon=gparted
Terminal=false
Type=Application
Categories=Application;System;
StartupNotify=true
EOF

# ZenBuild
cp $buildir/build-$softname.sh $dest/usr/src/$softname-$softversion

# set target permissions
chown -R root:root $dest

cd $dest
find . -perm 664 -exec chmod 644 {} \;
find . -perm 600 -exec chmod 644 {} \;
find . -perm 444 -exec chmod 644 {} \;
find . -perm 400 -exec chmod 644 {} \;
find . -perm 440 -exec chmod 644 {} \;
find . -perm 777 -exec chmod 755 {} \;
find . -perm 775 -exec chmod 755 {} \;
find . -perm 511 -exec chmod 755 {} \;
find . -perm 711 -exec chmod 755 {} \;
find . -perm 555 -exec chmod 755 {} \;

# real packaging work:
cd $dest
makepkg -l y -c n $dest.txz

# computes the md5sum signature for the package
cd $buildir
md5sum $package.txz > $package.md5

# .dep
cd $buildir
echo -e "atk,cairo,cairomm,expat,fontconfig,freetype,\
gcc,gcc-g++,glib2,glibmm,gtk+2,gtkmm,lvm2,libX11,libXau,libXcomposite,libXcursor,\
libXdamage,libXdmcp,libXext,libXfixes,libXi,libXinerama,libXrandr,libXrender,\
libpng,libsigc++,libxcb,ncurses,pango,pangomm,parted,pixman,readline,\
util-linux-ng,zlib" > $package.dep

# src file
echo http://zenwalk.pinguix.com/user-accounts/bip/EXTRA/xap/gparted/source/build-gparted.sh > $package.src
echo $source >> $package.src

# erase
rm -rf $src
rm -rf $dest

# log ;)
) 2>&1 | tee "$softname-$softversion-build.log"
